@@ -449,14 +449,14 @@ class Point(TypeEngine[_python_Point]):
         return _python_Point
 
 
-class JSON(TypeEngine[Any]):
+class JSON[T](TypeEngine[dict | list | T]):
     """JSON data type."""
 
     __visit_name__ = "JSON"
 
     @property
-    def python_type(self) -> Type[dict]:
-        return dict
+    def python_type(self) -> T | Type[dict | list]:
+        return dict | list
 
 
 type UuidType = str | _python_UUID
@@ -651,6 +651,8 @@ _type_dicc: dict[Any, TypeEngine[Any]] = {
 
 
 def resolve_primitive_types[T](value: T) -> TypeEngine[T]:
+    if issubclass(value, TypeEngine):
+        return value()
     if inspect.isclass(value):
         type_ = _type_dicc.get(value, None)
 
