@@ -2,15 +2,13 @@ from __future__ import annotations
 from typing import Any, Optional, Type, dataclass_transform, TYPE_CHECKING
 import json
 
-from ormlambda.sql import Column
-from ormlambda.sql import ForeignKey
-from ormlambda.util.module_tree.dfs_traversal import DFSTraversal
-from ormlambda.sql.ddl import CreateTable
-from ormlambda.util import make_hashable 
+from ormlambda.sql.ddl import CreateTable, DropTable
+from ormlambda import util
 
 if TYPE_CHECKING:
-    from ormlambda.statements import BaseStatement
+    from ormlambda.sql import Column
     from ormlambda.dialects import Dialect
+    from ormlambda import ForeignKey
 
 from .table_constructor import __init_constructor__
 
@@ -34,6 +32,7 @@ class TableMeta(type):
             raise Exception(f"class variable '__table_name__' of '{cls_object.__name__}' class must be 'str'")
 
         self = __init_constructor__(cls_object)
+
         return self
 
     def __repr__(cls: "Table") -> str:
@@ -85,7 +84,7 @@ class Table(metaclass=TableMeta):
 
         dicc: dict[str, str] = {x: str(getattr(self, x)) for x in self.__annotations__}
         equal_loop = ["=".join((x, __cast_long_variables(y))) for x, y in dicc.items()]
-        return f'{self.__class__.__name__}({", ".join(equal_loop)})'
+        return f"{self.__class__.__name__}({', '.join(equal_loop)})"
 
     def __getitem__[TProp](self, value: str | Column[TProp]) -> Optional[TProp]:
         name = value if isinstance(value, str) else value.column_name
@@ -94,21 +93,40 @@ class Table(metaclass=TableMeta):
         return None
 
     def to_dict(self) -> dict[str, str | int]:
+        def make_hashable(item: Any) -> Any:
+            if isinstance(item, dict):
+                return tuple(sorted((k, make_hashable(x)) for k, x in item.items()))
+
+            if isinstance(item, (list | set)):
+                return tuple(make_hashable(x) for x in item)
+            if hasattr(item, "__iter__") and not isinstance(item, str | bytes):
+                try:
+                    return tuple(make_hashable(x) for x in item)
+                except TypeError:
+                    return item  # if it fails, it's already hashable
+            return item
+
         dicc: dict[str, Any] = {}
         for x in self.__annotations__:
             value = getattr(self, x)
             dicc[x] = make_hashable(value)
         return dicc
 
+    @util.preload_module("ormlambda.sql")
     @classmethod
     def get_pk(cls) -> Optional[Column]:
+        Column = util.preloaded.sql_column.Column
+        ColumnProxy = util.preloaded.sql_column.ColumnProxy
         for obj in cls.__dict__.values():
-            if isinstance(obj, Column) and obj.is_primary_key:
+            if isinstance(obj, Column | ColumnProxy) and obj.is_primary_key:
                 return obj
         return None
 
+    @util.preload_module("ormlambda.sql")
     @classmethod
     def get_columns(cls) -> tuple[Column, ...]:
+        Column = util.preloaded.sql_column.Column
+
         return tuple([x for x in cls.__annotations__.values() if isinstance(x, Column)])
 
     @classmethod
@@ -117,48 +135,13 @@ class Table(metaclass=TableMeta):
             if name == key:
                 return value
 
-    @classmethod
-    def create_table_query(cls, statement: BaseStatement) -> str:
-        """It's classmethod because of it does not matter the columns values to create the table"""
-        from ormlambda.sql.schema_generator import SchemaGeneratorFactory
-
-        return SchemaGeneratorFactory.get_generator(statement._dialect).create_table(cls)
-
     @classmethod
     def create_table(cls, dialect: Dialect) -> str:
         return CreateTable(cls).compile(dialect).string
 
     @classmethod
-    def find_dependent_tables(cls) -> tuple["Table", ...]:
-        """Work in progress"""
-        return
-
-        # TODOL: Dive into new way to return dependent tables
-        def get_involved_tables(graph: dict[Table, list[Table]], table_name: str) -> None:
-            """
-            Create a graph to be ordered
-            """
-            table = ForeignKey[Table, Table].MAPPED[table_name]
-            for x in table.referenced_tables:
-                if data := ForeignKey.MAPPED.get(x, None):
-                    get_involved_tables(graph, data.table_object.__table_name__)
-
-            graph[table.table_object.__table_name__] = list(table.referenced_tables)
-            return None
-
-        graph: dict[Table, list[Table]] = {}
-        dependent = ForeignKey.MAPPED.get(cls.__table_name__, None)
-        if dependent is None:
-            return tuple([])
-
-        graph[cls.__table_name__] = list(dependent.referenced_tables)
-        get_involved_tables(graph, cls.__table_name__)
-
-        dfs = DFSTraversal.sort(graph)
-
-        order_table = dfs[: dfs.index(cls.__table_name__)]
-
-        return [ForeignKey.MAPPED[x].table_object for x in order_table]
+    def drop_table(cls, dialect: Dialect) -> str:
+        return DropTable(cls).compile(dialect).string
 
     def __eq__(self, __value: Any) -> bool:
         return hash(self) == hash(__value)
@@ -172,6 +155,9 @@ class Table(metaclass=TableMeta):
             return f"`{cls.__table_name__}_{column}`"
         return cls.__table_name__
 
+    @util.preload_module("ormlambda.sql")
     @classmethod
     def foreign_keys(cls) -> dict[str, ForeignKey]:
+        ForeignKey = util.preloaded.sql_foreign_key.ForeignKey
+
         return {key: value for key, value in cls.__dict__.items() if isinstance(value, ForeignKey)}
